==> Paws-0.35.tar.gz: Paws-0.35/lib/Paws/CodePipeline/OutputArtifact.pm <==
package Paws::CodePipeline::OutputArtifact;
  use Moose;
  has Name => (is => 'ro', isa => 'Str', request_name => 'name', traits => ['NameInRequest'], required => 1);
1;

### main pod documentation begin ###

=head1 NAME

Paws::CodePipeline::OutputArtifact

=head1 USAGE

This class represents one of two things:

=head3 Arguments in a call to a service

Use the attributes of this class as arguments to methods. You shouldn't make instances of this class. 
Each attribute should be used as a named argument in the calls that expect this type of object.

As an example, if Att1 is expected to be a Paws::CodePipeline::OutputArtifact object:

  $service_obj->Method(Att1 => { Name => $value, ..., Name => $value  });

=head3 Results returned from an API call

Use accessors for each attribute. If Att1 is expected to be an Paws::CodePipeline::OutputArtifact object:

  $result = $service_obj->Method(...);
  $result->Att1->Name

=head1 DESCRIPTION

Represents information about the output of an action.

=head1 ATTRIBUTES


=head2 B<REQUIRED> Name => Str

  The name of the output of an artifact, such as "My App".

The input artifact of an action must exactly match the output artifact
declared in a preceding action, but the input artifact does not have to
be the next action in strict sequence from the action that provided the
output artifact. Actions in parallel can declare different output
artifacts, which are in turn consumed by different following actions.

Output artifact names must be unique within a pipeline.



=head1 SEE ALSO

This class forms part of L<Paws>, describing an object used in L<Paws::CodePipeline>

=head1 BUGS and CONTRIBUTIONS

The source code is located here: https://github.com/pplu/aws-sdk-perl

Please report bugs to: https://github.com/pplu/aws-sdk-perl/issues

=cut

==> Paws-0.42.tar.gz: Paws-0.42/lib/Paws/CodePipeline/OutputArtifact.pm <==
package Paws::CodePipeline::OutputArtifact;
  use Moose;
  has Name => (is => 'ro', isa => 'Str', request_name => 'name', traits => ['NameInRequest'], required => 1);
1;

### main pod documentation begin ###

=head1 NAME

Paws::CodePipeline::OutputArtifact

=head1 USAGE

This class represents one of two things:

=head3 Arguments in a call to a service

Use the attributes of this class as arguments to methods. You shouldn't make instances of this class. 
Each attribute should be used as a named argument in the calls that expect this type of object.

As an example, if Att1 is expected to be a Paws::CodePipeline::OutputArtifact object:

  $service_obj->Method(Att1 => { Name => $value, ..., Name => $value  });

=head3 Results returned from an API call

Use accessors for each attribute. If Att1 is expected to be an Paws::CodePipeline::OutputArtifact object:

  $result = $service_obj->Method(...);
  $result->Att1->Name

=head1 DESCRIPTION

Represents information about the output of an action.

=head1 ATTRIBUTES


=head2 B<REQUIRED> Name => Str

  The name of the output of an artifact, such as "My App".

The input artifact of an action must exactly match the output artifact
declared in a preceding action, but the input artifact does not have to
be the next action in strict sequence from the action that provided the
output artifact. Actions in parallel can declare different output
artifacts, which are in turn consumed by different following actions.

Output artifact names must be unique within a pipeline.



=head1 SEE ALSO

This class forms part of L<Paws>, describing an object used in L<Paws::CodePipeline>

=head1 BUGS and CONTRIBUTIONS

The source code is located here: L<https://github.com/pplu/aws-sdk-perl>

Please report bugs to: L<https://github.com/pplu/aws-sdk-perl/issues>

=cut
